package secret

import (
	"time"
)

// VaultMetadata contains information about a vault
type VaultMetadata struct {
	Name            string    `json:"name"`
	CreatedAt       time.Time `json:"createdAt"`
	Description     string    `json:"description,omitempty"`
	DerivationIndex uint32    `json:"derivation_index"`
	LongTermKeyHash string    `json:"long_term_key_hash"` // Double SHA256 hash of derived long-term private key
	MnemonicHash    string    `json:"mnemonic_hash"`      // Double SHA256 hash of mnemonic for index tracking
}

// UnlockerMetadata contains information about an unlocker
type UnlockerMetadata struct {
	ID        string    `json:"id"`
	Type      string    `json:"type"` // passphrase, pgp, keychain
	CreatedAt time.Time `json:"createdAt"`
	Flags     []string  `json:"flags,omitempty"`
}

// SecretMetadata contains information about a secret
type SecretMetadata struct {
	Name      string    `json:"name"`
	CreatedAt time.Time `json:"createdAt"`
	UpdatedAt time.Time `json:"updatedAt"`
}

// Configuration represents the global configuration
type Configuration struct {
	DefaultVault string `json:"defaultVault,omitempty"`
}
